import Head from 'next/head';
import HeroPc from './components/HeroPc';
import HeroMobile from './components/HeroMobile';
import TrendingTvSlider from './components/TrendingTvSlider';
import TrendingMovieSlider from './components/TrendingMovieSlider';
import NetworkSlider from './components/NetworkSlider';
import CompanySlider from './components/CompanySlider';
import LatestGrid from './components/LatestGrid';
import AfricanMovieSlider from './components/AfricanMovieSlider';
import AdSense from '@/app/components/AdSense';
import DownloadPopup from './components/DownloadPopup'; // Import the DownloadPopup component

export default function HomePage() {
  return (
    <>
      <Head>
        <title>Delgor - Your Ultimate Movie and TV Show Streaming Platform</title>
        <meta
          name="description"
          content="Discover the latest and trending movies, TV shows, and African films on Delgor. Stream your favorite content with a futuristic design and seamless experience."
        />
        <meta name="keywords" content="movies, TV shows, streaming, African movies, Delgor, trending movies, watch online" />
        <meta property="og:title" content="Delgor - Your Ultimate Movie and TV Show Streaming Platform" />
        <meta
          property="og:description"
          content="Discover the latest and trending movies, TV shows, and African films on Delgor. Stream your favorite content with a futuristic design and seamless experience."
        />
        <meta property="og:type" content="website" />
        <meta property="og:url" content="https://www.delgor.com" />
        <meta property="og:image" content="/images/ogdelgor.png" />
        <meta property="og:image:width" content="1200" />
        <meta property="og:image:height" content="630" />
        <meta property="og:site_name" content="Delgor" />
        <meta property="twitter:card" content="summary_large_image" />
        <meta property="twitter:title" content="Delgor - Your Ultimate Movie and TV Show Streaming Platform" />
        <meta
          property="twitter:description"
          content="Discover the latest and trending movies, TV shows, and African films on Delgor. Stream your favorite content with a futuristic design and seamless experience."
        />
        <meta property="twitter:image" content="/images/ogdelgor.png" />
        <link rel="canonical" href="https://www.delgor.com" />
      </Head>

      <div className="relative">
        {/* Include Download Popup */}
        <DownloadPopup />

        {/* Hero section */}
        <div className="hidden md:block">
          <HeroPc />
        </div>
        <div className="block md:hidden">
          <HeroMobile />
        </div>
        {/* Trending TV Shows Slider */}
        <div className="mt-8">
          <TrendingTvSlider />
        </div>
      
        {/* Trending Movies Slider */}
        <div className="mt-8">
          <TrendingMovieSlider />
        </div>

        {/* Popular Networks Slider */}
        <div className="mt-8">
          <NetworkSlider />
        </div>

        {/* Top Production Companies Slider */}
        <div className="mt-8">
          <CompanySlider />
        </div>
        {/* AdSense Ad between Sliders */}
        <div className="my-8 w-full">
          <AdSense />
        </div>
        {/* African Movies Slider */}
        <div className="mt-8">
          <AfricanMovieSlider />
        </div>

        {/* Latest Movies and TV Series Grid */}
        <div className="mt-8">
          <LatestGrid />
        </div>

        {/* Final AdSense Ad at the Bottom */}
        <div className="my-8 w-full">
          <AdSense />
        </div>
      </div>
    </>
  );
}
